require_relative 'spec_helper'
require_relative '../lib/string_swap'

describe String do
  describe '#swap' do
    it 'should replace an occurence of one substring with another' do
      expect('this'.swap 'this', 'that').to eq('that')
    end

    it 'should replace an occurence of one substring with another and vice versa' do
      expect('this and that'.swap 'this', 'that').to eq('that and this')
    end

    it 'should replace all occurences of one substring with another' do
      expect('this and this'.swap 'this', 'that').to eq('that and that')
    end

    it 'should replace all occurences of one substring with another and vice versa' do
      expect('this and that, that and this'.swap 'this', 'that').to eq('that and this, this and that')
    end

    it 'should replace all occurences of one substring with another and vice versa without reordering surrounding text' do
      expect('abc:def:ghi'.swap ':', '/').to eq('abc/def/ghi')
    end

    # I'm not quite sure how to test this yet
    it 'should work without temporarily replacing one of the substrings with a substring that already exists in the string'

    it 'should allow arrays of strings as arguments' do
      expect('this and that, the other and the same'.swap ['this', 'that'], ['the other', 'the same']).to eq('that and this, the same and the other')
    end

    it 'should reject arguments that are not a string or array of strings' do
      expect { 'this'.swap /regex/, /arguments/ }.to raise_error(ArgumentError, 'only strings, or arrays of string pairs are acceptable arguments')
      expect { 'this'.swap [/regex/, /arguments/], [/in/, /arrays/] }.to raise_error(ArgumentError, 'only strings, or arrays of string pairs are acceptable arguments')
    end
  end
end
